.. _phoenixUtils:

PHOENIX tools
==================

"PHOENIX is a general-purpose state-of-the-art stellar and planetary atmosphere code" developed at the
Hamburger Sternwarte (`PHOENIX home <http://www.hs.uni-hamburg.de/EN/For/ThA/phoenix/index.html>`_).

Here, we merely provide a number of routines to support work with the output.

.. currentmodule:: PyAstronomy.pyasl.phoenixUtils
.. autofunction:: decomposeFilename
.. autofunction:: readUnit7
.. autofunction:: readDTable
